@@ -7,7 +7,6 @@ from enum import Enum, auto
 from typing import Any, Dict
 
 import cloudscraper
-import cfscrape
 
 logger = logging.getLogger(__name__)
 
@@ -169,8 +168,7 @@ class Garmin:
 
         self.garmin_headers = {"NK": "NT"}
 
-        # self.session = cloudscraper.CloudScraper()
-        self.session = cfscrape.create_scraper()
+        self.session = cloudscraper.CloudScraper()
         self.sso_rest_client = ApiClient(
             self.session,
             self.garmin_connect_sso_url,
